package cn.com.qmth.scancentral.service.impl;

import cn.com.qmth.scancentral.dao.StudentDao;
import cn.com.qmth.scancentral.service.ExamService;
import cn.com.qmth.scancentral.service.ImageCheckService;
import cn.com.qmth.scancentral.util.MathUtil;
import cn.com.qmth.scancentral.util.PageUtil;
import cn.com.qmth.scancentral.vo.imagecheck.ImageCheckDetailVo;
import cn.com.qmth.scancentral.vo.imagecheck.ImageCheckQuery;
import cn.com.qmth.scancentral.vo.imagecheck.ImageCheckVo;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.qmth.boot.core.collection.PageResult;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.List;

@Component
public class ImageCheckServiceImpl implements ImageCheckService {

    private static final Logger log = LoggerFactory.getLogger(ImageCheckServiceImpl.class);

    @Autowired
    private ExamService examService;

    @Autowired
    private StudentDao studentDao;

    @Override
    public List<ImageCheckVo> list(Long examId) {
        if (examId == null) {
            throw new IllegalArgumentException("考试ID不能为空");
        }
        List<ImageCheckVo> result = studentDao.countImageCheck(examId);

        for (ImageCheckVo vo : result) {
            double progress = MathUtil.percentage(vo.getTotalCount() - vo.getFailedCount(), vo.getTotalCount());
            vo.setImageCheckProgress(progress);
        }

        return result;
    }

    @Override
    public PageResult<ImageCheckDetailVo> detailList(ImageCheckQuery query) {
        if (query.getExamId() == null) {
            throw new IllegalArgumentException("考试ID不能为空");
        }
        if (StringUtils.isBlank(query.getSubjectCode())) {
            throw new IllegalArgumentException("科目代码不能为空");
        }
        IPage<ImageCheckDetailVo> page = studentDao.queryImageCheckDetail(new Page<>(query.getPageNumber(), query.getPageSize()), query);

        for (ImageCheckDetailVo vo : page.getRecords()) {
            vo.setFailed(vo.getFailedCount() > 0);
        }

        return PageUtil.of(page);
    }

}
